@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2004-2024 Edward F. Valeev
+*  Copyright (C) 2004-2026 Edward F. Valeev
 *
 *  This file is part of Libint library.
 *
@@ -126,9 +126,9 @@ namespace libint2 {
        *       The expected location of the file is determined by BasisSet::data_path as follows:
        *       <ol>
        *         <li> specified by LIBINT_DATA_PATH environmental variable, if defined </li>
-       *         <li> specified by DATADIR macro variable, if defined </li>
-       *         <li> specified by SRCDATADIR macro variable, if defined </li>
-       *         <li> hardwired to directory \c /clangarm64/share/libint/2.9.0/basis </li>
+       *         <li> specified by LIBINT_DATADIR macro variable, if defined </li>
+       *         <li> specified by LIBINT_SRCDATADIR macro variable, if defined </li>
+       *         <li> hardwired to directory \c /clangarm64/share/libint/2.12.0/basis </li>
        *       </ol>
        */
       BasisSet(std::string name,
@@ -171,7 +171,8 @@ namespace libint2 {
               } // shell loop
             }
             else if (throw_if_no_match) {  // not found? throw, if needed
-              std::string errmsg(std::string("did not find the basis for this Z in ") +
+              std::string errmsg(std::string("did not find the basis for Z=") +
+                      std::to_string(Z) + " in " +
                       basis_lib_path + PATH_SEPARATOR + basis_component_names[comp_idx] + ".g94");
               throw std::logic_error(errmsg);
             }
@@ -402,9 +403,9 @@ namespace libint2 {
       /** determines the path to the data directory, as follows:
        *       <ol>
        *         <li> specified by LIBINT_DATA_PATH environmental variable, if defined </li>
-       *         <li> specified by DATADIR macro variable, if defined </li>
-       *         <li> specified by SRCDATADIR macro variable, if defined </li>
-       *         <li> hardwired to directory \c /clangarm64/share/libint/2.9.0/basis </li>
+       *         <li> specified by LIBINT_DATADIR macro variable, if defined </li>
+       *         <li> specified by LIBINT_SRCDATADIR macro variable, if defined </li>
+       *         <li> hardwired to directory \c /clangarm64/share/libint/2.12.0/basis </li>
        *       </ol>
        *  @throw std::system_error if the path is not valid, or cannot be determined
        *  @return valid path to the data directory
@@ -416,12 +417,12 @@ namespace libint2 {
           path = data_path_env;
         }
         else {
-#if defined(DATADIR)
-          path = std::string{DATADIR};
-#elif defined(SRCDATADIR)
-          path = std::string{SRCDATADIR};
+#if defined(LIBINT_DATADIR)
+          path = std::string{LIBINT_DATADIR};
+#elif defined(LIBINT_SRCDATADIR)
+          path = std::string{LIBINT_SRCDATADIR};
 #else
-          path = std::string("/clangarm64/share/libint/2.9.0");
+          path = std::string("/clangarm64/share/libint/2.12.0");
 #endif
         }
         // validate basis_path = path + "/basis"
@@ -481,7 +482,7 @@ namespace libint2 {
                                                                             ) {
 
         std::locale locale(locale_name.c_str());  // TODO omit c_str() with up-to-date stdlib
-        std::vector<std::vector<libint2::Shell>> ref_shells(118); // 118 = number of chemical elements
+        std::vector<std::vector<libint2::Shell>> ref_shells(119); // 118 = number of chemical elements + 1 because we insert at(Z)
         std::ifstream is(file_dot_g94);
         is.imbue(locale);
 
@@ -620,15 +621,15 @@ namespace libint2 {
         return ref_shells;
       }
 
-      DEPRECATED static size_t nbf(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static size_t nbf(const std::vector<libint2::Shell>& shells) {
         return libint2::nbf(shells);
       }
 
-      DEPRECATED static size_t max_nprim(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static size_t max_nprim(const std::vector<libint2::Shell>& shells) {
         return libint2::max_nprim(shells);
       }
 
-      DEPRECATED static int max_l(const std::vector<libint2::Shell>& shells) {
+      LIBINT2_DEPRECATED static int max_l(const std::vector<libint2::Shell>& shells) {
         return libint2::max_l(shells);
       }
 
